git/list[1] front-page[2] threads[3] people[4] search[5] about
 

[PATCH 01/34] t0450: *.txt -> *.adoc fixes

From
Todd Zullinger <tmz@pobox.com>
Date
Mar 3, 2025, 20:43 UTC
Message-ID
<20250303204443.360595-2-tmz@pobox.com>
In-Reply-To
<20250303204443.360595-1-tmz@pobox.com>

After 1f010d6bdf (doc: use .adoc extension for AsciiDoc files, 2025-01-20), we no longer matched any files in this test. The result is that we did not test for mismatches in the documentation and --help output.

Adjust the test to look at the renamed *.adoc files.
Signed-off-by: Todd Zullinger <tmz@pobox.com>
---
 t/t0450-txt-doc-vs-help.sh                    | 50 +++++++++----------
 ...t-help-mismatches => adoc-help-mismatches} |  0
 2 files changed, 25 insertions(+), 25 deletions(-)
 rename t/t0450/{txt-help-mismatches => adoc-help-mismatches} (100%)
diff --git a/t/t0450-txt-doc-vs-help.sh b/t/t0450-txt-doc-vs-help.sh
index 853101b86e..2f7504ae7e 100755
--- a/t/t0450-txt-doc-vs-help.sh
+++ b/t/t0450-txt-doc-vs-help.sh
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-test_description='assert (unbuilt) Documentation/*.txt and -h output
+test_description='assert (unbuilt) Documentation/*.adoc and -h output
 
 Run this with --debug to see a summary of where we still fail to make
 the two versions consistent with one another.'
@@ -11,11 +11,11 @@ test_expect_success 'setup: list of builtins' '
 	git --list-cmds=builtins >builtins
 '
 
-test_expect_success 'list of txt and help mismatches is sorted' '
-	sort -u "$TEST_DIRECTORY"/t0450/txt-help-mismatches >expect &&
-	if ! test_cmp expect "$TEST_DIRECTORY"/t0450/txt-help-mismatches
+test_expect_success 'list of adoc and help mismatches is sorted' '
+	sort -u "$TEST_DIRECTORY"/t0450/adoc-help-mismatches >expect &&
+	if ! test_cmp expect "$TEST_DIRECTORY"/t0450/adoc-help-mismatches
 	then
-		BUG "please keep the list of txt and help mismatches sorted"
+		BUG "please keep the list of adoc and help mismatches sorted"
 	fi
 '
 
@@ -40,20 +40,20 @@ help_to_synopsis () {
 	echo "$out"
 }
 
-builtin_to_txt () {
-       echo "$GIT_BUILD_DIR/Documentation/git-$1.txt"
+builtin_to_adoc () {
+       echo "$GIT_BUILD_DIR/Documentation/git-$1.adoc"
 }
 
-txt_to_synopsis () {
+adoc_to_synopsis () {
 	builtin="$1" &&
 	out_dir="out/$builtin" &&
-	out="$out_dir/txt.synopsis" &&
+	out="$out_dir/adoc.synopsis" &&
 	if test -f "$out"
 	then
 		echo "$out" &&
 		return 0
 	fi &&
-	b2t="$(builtin_to_txt "$builtin")" &&
+	b2t="$(builtin_to_adoc "$builtin")" &&
 	sed -n \
 		-E '/^\[(verse|synopsis)\]$/,/^$/ {
 			/^$/d;
@@ -109,29 +109,29 @@ do
 		fi
 	'
 
-	txt="$(builtin_to_txt "$builtin")" &&
-	preq="$(echo BUILTIN_TXT_$builtin | tr '[:lower:]-' '[:upper:]_')" &&
+	adoc="$(builtin_to_adoc "$builtin")" &&
+	preq="$(echo BUILTIN_ADOC_$builtin | tr '[:lower:]-' '[:upper:]_')" &&
 
-	if test -f "$txt"
+	if test -f "$adoc"
 	then
 		test_set_prereq "$preq"
 	fi &&
 
-	# *.txt output assertions
-	test_expect_success "$preq" "$builtin *.txt SYNOPSIS has dashed labels" '
-		check_dashed_labels "$(txt_to_synopsis "$builtin")"
+	# *.adoc output assertions
+	test_expect_success "$preq" "$builtin *.adoc SYNOPSIS has dashed labels" '
+		check_dashed_labels "$(adoc_to_synopsis "$builtin")"
 	'
 
 	# *.txt output consistency assertions
 	result=
-	if grep -q "^$builtin$" "$TEST_DIRECTORY"/t0450/txt-help-mismatches
+	if grep -q "^$builtin$" "$TEST_DIRECTORY"/t0450/adoc-help-mismatches
 	then
 		result=failure
 	else
 		result=success
 	fi &&
 	test_expect_$result "$preq" "$builtin -h output and SYNOPSIS agree" '
-		t2s="$(txt_to_synopsis "$builtin")" &&
+		t2s="$(adoc_to_synopsis "$builtin")" &&
 		if test "$builtin" = "merge-tree"
 		then
 			test_when_finished "rm -f t2s.new" &&
@@ -140,17 +140,17 @@ do
 		fi &&
 		h2s="$(help_to_synopsis "$builtin")" &&
 
 		# The *.txt and -h use different spacing for the
 		# alignment of continued usage output, normalize it.
-		align_after_nl "$builtin" <"$t2s" >txt &&
+		align_after_nl "$builtin" <"$t2s" >adoc &&
 		align_after_nl "$builtin" <"$h2s" >help &&
-		test_cmp txt help
+		test_cmp adoc help
 	'
 
-	if test_have_prereq "$preq" && test -e txt && test -e help
+	if test_have_prereq "$preq" && test -e adoc && test -e help
 	then
 		test_debug '
-			if test_cmp txt help >cmp 2>/dev/null
+			if test_cmp adoc help >cmp 2>/dev/null
 			then
 				echo "=== DONE: $builtin ==="
 			else
@@ -161,7 +161,7 @@ do
 
 		# Not in test_expect_success in case --run is being
 		# used with --debug
-		rm -f txt help tmp 2>/dev/null
+		rm -f adoc help tmp 2>/dev/null
 	fi
 done <builtins
 
@@ -109,29 +109,29 @@ do
 	'
 
-	# *.txt output consistency assertions
+	# *.adoc output consistency assertions
 	result=
@@ -140,17 +140,17 @@ do
 		h2s="$(help_to_synopsis "$builtin")" &&
 
-		# The *.txt and -h use different spacing for the
+		# The *.adoc and -h use different spacing for the
 		# alignment of continued usage output, normalize it.
diff --git a/t/t0450/txt-help-mismatches b/t/t0450/adoc-help-mismatches
similarity index 100%
rename from t/t0450/txt-help-mismatches
rename to t/t0450/adoc-help-mismatches
-- 
2.49.0.rc0
Previous: Todd ZullingerNext: Junio C Hamano
Message 2 of 43 in “misc *.txt -> *.adoc fixes”
  1. 00/34 misc *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  2. 01/34 t0450: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  3. Junio C HamanoMar 3, 2025
  4. Todd ZullingerMar 3, 2025
  5. Junio C HamanoMar 3, 2025
  6. Todd ZullingerMar 4, 2025
  7. 02/34 .gitattributes: more *.txt -> *.adoc updatesTodd Zullinger, Mar 3, 2025
  8. 03/34 doc: remove unneeded .gitattributesTodd Zullinger, Mar 3, 2025
  9. Junio C HamanoMar 3, 2025
  10. 04/34 Makefile: update reference to technical/racy-git.adocTodd Zullinger, Mar 3, 2025
  11. 05/34 README: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  12. 06/34 CodingGuidelines: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  13. 07/34 MyFirstContribution: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  14. 08/34 MyFirstObjectWalk: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  15. 09/34 howto/new-command: update reference to builtin docsTodd Zullinger, Mar 3, 2025
  16. Junio C HamanoMar 3, 2025
  17. 10/34 technical/partial-clone: update reference to rev-list-options.adocTodd Zullinger, Mar 3, 2025
  18. 11/34 doc: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  19. 12/34 advice.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  20. 13/34 apply.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  21. 14/34 builtin.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  22. 15/34 config.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  23. 16/34 contrib/long-running-filter: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  24. 17/34 diff.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  25. 18/34 diffcore.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  26. 19/34 fsck.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  27. 20/34 list-objects-filter-options.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  28. 21/34 object-name.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  29. 22/34 parse-options.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  30. 23/34 pseudo-merge.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  31. 24/34 refs.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  32. 25/34 setup.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  33. 26/34 simple-ipc.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  34. 27/34 t/helper/test-rot13-filter.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  35. 28/34 t6012: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  36. 29/34 t6434: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  37. 30/34 trace2.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  38. 31/34 trace2/tr2_sysenv.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  39. 32/34 transport.h: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  40. 33/34 unpack-trees.c: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  41. 34/34 xdiff: *.txt -> *.adoc fixesTodd Zullinger, Mar 3, 2025
  42. brian m. carlsonMar 3, 2025
  43. Junio C HamanoMar 3, 2025

Read the whole thread, see it on lore, or plain text.

$ cat FOOTERMessages come from the public archive at lore.kernel.org/git, fetched every hour. The front page is chosen and written each morning by an AI editor and can be wrong; the threads themselves are the record. About and API. For agents: an MCP server at https://gitlist.dev/mcp, and any thread, story or person page as Markdown by adding .md to its URL (or sending Accept: text/markdown). Details in /llms.txt.